unquad.estimation.weighted\_conformal
=====================================

.. automodule:: unquad.estimation.weighted_conformal

   
   .. rubric:: Classes

   .. autosummary::
   
      WeightedConformalDetector
   